pub trait AppTrait {
// Required method
fn load_icon(&self) -> Result<RustImageData>;
}Expand description
This trait specifies the methods that an app should implement, such as loading its logo
pub trait AppTrait {
// Required method
fn load_icon(&self) -> Result<RustImageData>;
}This trait specifies the methods that an app should implement, such as loading its logo