pub struct RustImageData { /* private fields */ }Trait Implementations
Sourceimpl Debug for RustImageData
impl Debug for RustImageData
Sourceimpl RustImage for RustImageData
impl RustImage for RustImageData
fn is_empty(&self) -> bool
Sourcefn from_path(path: &str) -> ImageResult<Self>
fn from_path(path: &str) -> ImageResult<Self>
Read image from file path
Sourcefn from_bytes(bytes: &[u8]) -> ImageResult<Self>
fn from_bytes(bytes: &[u8]) -> ImageResult<Self>
Create a new image from a byte slice
fn from_dynamic_image(image: DynamicImage) -> Self
Sourcefn thumbnail(&self, width: u32, height: u32) -> ImageResult<Self>
fn thumbnail(&self, width: u32, height: u32) -> ImageResult<Self>
Scale this image down to fit within a specific size.
Returns a new image. The image’s aspect ratio is preserved.
The image is scaled to the maximum possible size that fits
within the bounds specified by
nwidth and nheight. Read moreSourcefn resize(
&self,
width: u32,
height: u32,
filter: FilterType,
) -> ImageResult<Self>
fn resize( &self, width: u32, height: u32, filter: FilterType, ) -> ImageResult<Self>
en: Adjust the size of the image without retaining the aspect ratio
zh: 调整图片大小,不保留长宽比
fn to_jpeg(&self) -> ImageResult<RustImageBuffer>
Sourcefn to_png(&self) -> ImageResult<RustImageBuffer>
fn to_png(&self) -> ImageResult<RustImageBuffer>
en: Convert to png format, the returned image is a new image, and the data itself will not be modified
zh: 转为 png 格式,返回的为新的图片,本身数据不会修改
fn to_bitmap(&self) -> ImageResult<RustImageBuffer>
fn save_to_path(&self, path: &str) -> ImageResult<()>